==> helper-8.x-1.22.tar.gz: helper/src/Theme.php <==
<?php

namespace Drupal\helper;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Extension\ThemeInstallerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;

/**
 * Helper service for working with themes.
 */
class Theme {

  /**
   * Theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  protected ThemeHandlerInterface $themeHandler;

  /**
   * Theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected ThemeManagerInterface $themeManager;

  /**
   * Theme installer.
   *
   * @var \Drupal\Core\Extension\ThemeInstallerInterface
   */
  protected ThemeInstallerInterface $themeInstaller;

  /**
   * Configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * Constructs a Theme helper.
   *
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
   *   Theme handler.
   * @param \Drupal\Core\Theme\ThemeManagerInterface $theme_manager
   *   Theme manager.
   * @param \Drupal\Core\Extension\ThemeInstallerInterface $theme_installer
   *   Theme installer.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Configuration factory.
   */
  public function __construct(ThemeHandlerInterface $theme_handler, ThemeManagerInterface $theme_manager, ThemeInstallerInterface $theme_installer, ConfigFactoryInterface $config_factory) {
    $this->themeHandler = $theme_handler;
    $this->themeManager = $theme_manager;
    $this->themeInstaller = $theme_installer;
    $this->configFactory = $config_factory;
  }

  /**
   * Checks if a theme is active as the current theme one of its subthemes.
   *
   * @param string $theme_name
   *   Theme name.
   *
   * @return bool
   *   TRUE if the theme is active, or FALSE otherwise.
   */
  public function isActive(string $theme_name): bool {
    // Check default frontend theme.
    $default_theme = $this->themeHandler->getDefault();
    if ($default_theme === $theme_name) {
      return TRUE;
    }

    // Check any base themes of default theme.
    if ($base_themes = $this->themeHandler->getBaseThemes($this->themeHandler->listInfo(), $default_theme)) {
      return array_key_exists($theme_name, $base_themes);
    }

    return FALSE;
  }

  /**
   * Sets the default theme.
   *
   * @param string $theme_name
   *   Theme name.
   */
  public function setDefault(string $theme_name): void {
    if (!$this->themeHandler->themeExists($theme_name)) {
      $this->themeInstaller->install([$theme_name]);
    }
    $this->configFactory->getEditable('system.theme')->set('default', $theme_name)->save();
    $this->themeManager->resetActiveTheme();
  }

}

==> helper-8.x-1.23.tar.gz: helper/src/Theme.php <==
<?php

namespace Drupal\helper;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ThemeHandlerInterface;
use Drupal\Core\Extension\ThemeInstallerInterface;
use Drupal\Core\Theme\ThemeManagerInterface;

/**
 * Helper service for working with themes.
 */
class Theme {

  /**
   * Theme handler.
   *
   * @var \Drupal\Core\Extension\ThemeHandlerInterface
   */
  protected ThemeHandlerInterface $themeHandler;

  /**
   * Theme manager.
   *
   * @var \Drupal\Core\Theme\ThemeManagerInterface
   */
  protected ThemeManagerInterface $themeManager;

  /**
   * Theme installer.
   *
   * @var \Drupal\Core\Extension\ThemeInstallerInterface
   */
  protected ThemeInstallerInterface $themeInstaller;

  /**
   * Configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * Constructs a Theme helper.
   *
   * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
   *   Theme handler.
   * @param \Drupal\Core\Theme\ThemeManagerInterface $theme_manager
   *   Theme manager.
   * @param \Drupal\Core\Extension\ThemeInstallerInterface $theme_installer
   *   Theme installer.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Configuration factory.
   */
  public function __construct(ThemeHandlerInterface $theme_handler, ThemeManagerInterface $theme_manager, ThemeInstallerInterface $theme_installer, ConfigFactoryInterface $config_factory) {
    $this->themeHandler = $theme_handler;
    $this->themeManager = $theme_manager;
    $this->themeInstaller = $theme_installer;
    $this->configFactory = $config_factory;
  }

  /**
   * Checks if a theme is active as the current theme one of its subthemes.
   *
   * @param string $theme_name
   *   Theme name.
   *
   * @return bool
   *   TRUE if the theme is active, or FALSE otherwise.
   */
  public function isActive(string $theme_name): bool {
    // Check default frontend theme.
    $default_theme = $this->themeHandler->getDefault();
    if ($default_theme === $theme_name) {
      return TRUE;
    }

    // Check any base themes of default theme.
    if ($base_themes = $this->themeHandler->getBaseThemes($this->themeHandler->listInfo(), $default_theme)) {
      return array_key_exists($theme_name, $base_themes);
    }

    return FALSE;
  }

  /**
   * Sets the default theme.
   *
   * @param string $theme_name
   *   Theme name.
   *
   * @return bool
   *   TRUE if the default theme was updated, or FALSE if the requested theme
   *   was already the default.
   */
  public function setDefault(string $theme_name): bool {
    if (!$this->themeHandler->themeExists($theme_name)) {
      $this->themeInstaller->install([$theme_name]);
    }
    if ($this->themeHandler->getDefault() !== $theme_name) {
      $this->configFactory->getEditable('system.theme')->set('default', $theme_name)->save();
      $this->themeManager->resetActiveTheme();
      return TRUE;
    }
    return FALSE;
  }

}
